@@ -170,13 +170,14 @@ class Customer(object):
         result = {}
         key = 'cdr_start_date:{}'.format(self.name)
         REDIS_DB.set(key, start_conso)
-        REDIS_DB.expire(key, 30)
+        REDIS_DB.expire(key, 2592000)
         start = REDIS_DB.get(key)
         result = {
                 'code': '200',
                 'ident': self.name,
                 'date': str(start.decode('utf-8'))
                 }
+        LOGS.logger.info('key enregistré:{}'.format(key))
         return result
 
     def fup_defup(
@@ -190,6 +191,8 @@ class Customer(object):
             msg
             ):
         api_request = getattr(REST_CLIENT, method)
+        LOGS.logger.info(api_request)
+        LOGS.logger.info(params)
         response = api_request(
             '/fup',
             auth=(
@@ -245,6 +248,7 @@ class Customer(object):
             'code': '401',
             'message': 'NOK'
             }
+        bool_delete = False
         params = {}
         params['customer'] = self.name
         if bool_defup:
@@ -266,11 +270,11 @@ class Customer(object):
                 period = 'try'
                 method = 'post'
                 if bool_defup:
-                    params['actif'] = 'FALSE'
+                    params['actif'] = 'TRUE'
                     msg = 'Active'
                 else:
                     msg = 'Desactive'
-                    params['actif'] = 'TRUE'
+                    params['actif'] = 'FALSE'
             else:
                 period = 'hp'
                 params['period'] = period
@@ -290,6 +294,8 @@ class Customer(object):
                         period,
                         msg
                         )
+                    if result['code'] == '200':
+                        bool_delete = True
                 else:
                     result = {
                             'code': '201',
@@ -307,12 +313,14 @@ class Customer(object):
                         period,
                         msg
                         )
+                    if result['code'] == '200':
+                        bool_delete = True
                 else:
                     result = {
                             'code': '204',
                             'message': 'produit non {}'.format(msg)
                             }
-        if bool_defup:
+        if bool_delete and bool_defup:
             url = core.database_url(**FUPDB_CREDENTIALS)
             with records.Database(url) as db:
                 sql = "DELETE FROM customer WHERE name=:name"
@@ -701,7 +709,7 @@ class Customer(object):
             if for_real:
                 if info.get('fup_in'):  # à limiter
                     if info['period'] == 'try':
-                        params['actif'] = 'TRUE'
+                        params['actif'] = 'FALSE'
                     else:
                         params['period'] = info['period']
                     params['customer'] = self.name
@@ -734,7 +742,7 @@ class Customer(object):
                             conso=str(info['total'])
                             )
                     if info['period'] == 'try':
-                        params['actif'] = True
+                        params['actif'] = FALSE
                     else:
                         params['period'] = info['period']
                     params['customer'] = self.name
@@ -749,21 +757,21 @@ class Customer(object):
                     """
                 elif info.get('fup_out'):  # libérer
                     if info['period'] == 'try':
-                        params['actif'] = 'FALSE'
+                        params['actif'] = 'TRUE'
                         method = 'post'
                     else:
                         params['period'] = info['period']
                         method = 'delete'
-                    params['customer'] = self.name
-                    self.fup_defup(
-                        method,
-                        params,
-                        info['name'],
-                        False,
-                        str(info['total']),
-                        str(info['period']),
-                        'Defup'
-                        )
+                        params['customer'] = self.name
+                        self.fup_defup(
+                            method,
+                            params,
+                            info['name'],
+                            False,
+                            str(info['total']),
+                            str(info['period']),
+                            'Defup'
+                            )
                     """url = core.database_url(**FUPDB_CREDENTIALS)
                     with records.Database(url) as db:
                         sql = (
@@ -784,7 +792,7 @@ class Customer(object):
                             conso=str(info['total'])
                             )
                     if info['period'] == 'try':
-                        params['actif'] = False
+                        params['actif'] = TRUE
                     else:
                         params['period'] = info['period']
                     params['customer'] = self.name
